@@ -27,12 +27,9 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkdnd.h>
+#include <glib/gi18n.h>
+
+#include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
 #include <libwnck/screen.h>
@@ -43,6 +40,7 @@
 #include <string.h>
 
 #define TIMEOUT_ACTIVATE 1000
+#define SHOW_DESKTOP_ICON "user-desktop"
 
 
 typedef struct {
@@ -176,11 +174,11 @@ update_icon (ShowDesktopData *sdd)
 
 	error = NULL;
 	icon = gtk_icon_theme_load_icon (sdd->icon_theme,
-					 "gnome-fs-desktop",
+					 SHOW_DESKTOP_ICON,
 					 icon_size, 0, &error);
 
 	if (icon == NULL) {
-		g_printerr (_("Failed to load %s: %s\n"), "gnome-fs-desktop",
+		g_printerr (_("Failed to load %s: %s\n"), SHOW_DESKTOP_ICON,
 			    error ? error->message : _("Icon not found"));
 		if (error) {
 			g_error_free (error);
@@ -508,11 +506,11 @@ show_desktop_applet_fill (PanelApplet *applet)
 
 static void
 display_help_dialog (BonoboUIComponent *uic,
-                     ShowDesktopData         *sdd,
+                     ShowDesktopData   *sdd,
                      const gchar       *verbname)
 {
 	wncklet_display_help (sdd->applet, "user-guide",
-			      "user-guide.xml", "gospanel-564");
+			      "gospanel-564", SHOW_DESKTOP_ICON);
 }
 
 static void
@@ -539,7 +537,7 @@ display_about_dialog (BonoboUIComponent *uic,
 			       authors,
 			       documenters,
 			       translator_credits,
-			       "gnome-fs-desktop",
+			       SHOW_DESKTOP_ICON,
 			       "show-desktop",
 			       "show-desktop");
 }
