@@ -13,9 +13,10 @@
 #include <sys/wait.h>
 
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-authentication-manager.h>
 #include <libgnomeui/gnome-ui-init.h>
 
+#include <libpanel-util/panel-cleanup.h>
+
 #include "panel-gconf.h"
 #include "panel-profile.h"
 #include "panel-config-global.h"
@@ -34,11 +35,11 @@
 GSList *panels = NULL;
 GSList *panel_list = NULL;
 
-GtkTooltips *panel_tooltips = NULL;
-
-static char *deprecated_profile;
+static char     *deprecated_profile;
+static gboolean  replace = FALSE;
 
 static const GOptionEntry options[] = {
+  { "replace", 0, 0, G_OPTION_ARG_NONE, &replace, N_("Replace a currently running panel"), NULL },
   /* keep this for compatibilty with old GNOME < 2.10 */
   { "profile", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, &deprecated_profile, NULL, NULL },
   { NULL }
@@ -64,15 +65,15 @@ main (int argc, char **argv)
 				      GNOME_PARAM_GOPTION_CONTEXT, context,
 				      GNOME_PROGRAM_STANDARD_PROPERTIES,
 				      NULL);
+	panel_cleanup_register (PANEL_CLEAN_FUNC (g_object_unref), program);
 
+	g_set_application_name (_("Panel"));
 	gtk_window_set_default_icon_name (PANEL_ICON_PANEL);
 
-	if (!panel_shell_register ())
+	if (!panel_shell_register (replace)) {
+		panel_cleanup_do ();
 		return -1;
-
-	gnome_authentication_manager_init ();
-
-	panel_tooltips = gtk_tooltips_new ();
+	}
 
 	panel_action_protocol_init ();
 	panel_multiscreen_init ();
@@ -104,7 +105,7 @@ main (int argc, char **argv)
 				 "/desktop/gnome/interface",
 				 NULL);
 
-	g_object_unref (program);
+	panel_cleanup_do ();
 
 	return 0;
 }
